aboutsummaryrefslogtreecommitdiff
path: root/src/consensus/consensus.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/consensus/consensus.h')
-rw-r--r--src/consensus/consensus.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/consensus/consensus.h b/src/consensus/consensus.h
index 81f40593b2..6908565866 100644
--- a/src/consensus/consensus.h
+++ b/src/consensus/consensus.h
@@ -10,8 +10,8 @@
/** The maximum allowed size for a serialized block, in bytes (only for buffer size limits) */
static const unsigned int MAX_BLOCK_SERIALIZED_SIZE = 4000000;
-/** The maximum allowed cost for a block, see BIP 141 (network rule) */
-static const unsigned int MAX_BLOCK_COST = 4000000;
+/** The maximum allowed weight for a block, see BIP 141 (network rule) */
+static const unsigned int MAX_BLOCK_WEIGHT = 4000000;
/** The maximum allowed size for a block excluding witness data, in bytes (network rule) */
static const unsigned int MAX_BLOCK_BASE_SIZE = 1000000;
/** The maximum allowed number of signature check operations in a block (network rule) */